@@ -16,7 +16,7 @@ use Params::Validate qw/ validate validate_with /;
 
 use Digest::MD5 qw/ md5_hex /;
 
-our $VERSION = '1.0_0';
+our $VERSION = '1.0_1';
 
 use overload '""' => sub { $_[0]->name };
 
@@ -104,11 +104,11 @@ sub load_xml {
     $self->_set_id( $dom->findvalue('id/text()') );
     $self->_set_name( $dom->findvalue('name/text()') );
     $self->_set_created_at(
-        Time::Piece->new( str2time( $dom->findvalue('created_at/text()') ) )
-    );
+        scalar Time::Piece::gmtime(
+            str2time( $dom->findvalue('created_at/text()') ) ) );
     $self->_set_updated_at(
-        Time::Piece->new( str2time( $dom->findvalue('updated_at/text()') ) )
-    );
+        scalar Time::Piece::gmtime(
+            str2time( $dom->findvalue('updated_at/text()') ) ) );
     $self->_set_homepage_url( $dom->findvalue('homepage_url/text()') );
     $self->_set_avatar_url( $dom->findvalue('avatar_url/text()') );
     $self->_set_posts_count( $dom->findvalue('posts_count/text()') );
@@ -331,7 +331,7 @@ Ohloh Account API reference: http://www.ohloh.net/api/reference/account
 
 =head1 VERSION
 
-This document describes WWW::Ohloh::API version 1.0_0
+This document describes WWW::Ohloh::API version 1.0_1
 
 =head1 BUGS AND LIMITATIONS
 
