@@ -17,7 +17,7 @@ use WWW::Ohloh::API::StackEntry;
 
 use Params::Validate qw/ validate_with /;
 
-our $VERSION = '1.0_0';
+our $VERSION = '1.0_1';
 
 my @ohloh_of : Field : Arg(ohloh);
 my @request_url_of : Field : Arg(request_url) : Get( request_url );
@@ -53,8 +53,8 @@ sub load_xml {
     }
 
     $self->_set_updated_at(
-        Time::Piece->new( str2time( $dom->findvalue("updated_at/text()") ) )
-    );
+        scalar Time::Piece::gmtime(
+            str2time( $dom->findvalue("updated_at/text()") ) ) );
 
     if ( my ($account_xml) = $dom->findnodes('account[1]') ) {
         $account_of[$$self] = WWW::Ohloh::API::Account->new(
@@ -212,7 +212,7 @@ or removed from this stack as a L<Time::Piece> object.
 
 =for test
     isa_ok $result[0], 'Time::Piece';
-    is $result[0], 'Mon Mar 17 13:09:16 2008', 'updated_at()';
+    is $result[0], 'Mon Mar 17 17:09:16 2008', 'updated_at()';
 
 =head3 project_count
 
@@ -285,7 +285,7 @@ Ohloh Account API reference: http://www.ohloh.net/api/reference/stack
 
 =head1 VERSION
 
-This document describes WWW::Ohloh::API version 1.0_0
+This document describes WWW::Ohloh::API version 1.0_1
 
 =head1 BUGS AND LIMITATIONS
 
